/* goocanvas/goocanvasmmconfig.h.  Generated from goocanvasmmconfig.h.in by configure.  */
#ifndef _GOOCANVASMM_CONFIG_H
#define _GOOCANVASMM_CONFIG_H 1

#include "glibmmconfig.h"

/* version numbers */
#define GOOCANVASMM_MAJOR_VERSION 1
#define GOOCANVASMM_MINOR_VERSION 90
#define GOOCANVASMM_MICRO_VERSION 11
/* #undef GOOCANVASMM_VERSION */

#endif /* _GOOCANVASMM_CONFIG_H */

